////////////////////////////////////////////////////////////////////////////////
//DEXi: Implements a Multi-Attribute Decision Making algorithm developed by
//dr. Marko Bohanec (http://www-ai.ijs.si/MarkoBohanec/dex.html)
//
//Copyright (C) 2004 Asobi d.o.o. (www.asobi.si)
//Authors: dr. Marko Bohanec, Dusan Omercevic, Andrej Kogovsek
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU Lesser General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//Lesser General Public License for more details.
//
//You should have received a copy of the GNU Lesser General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
////////////////////////////////////////////////////////////////////////////////
package si.DEXi;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;


/**
 * Evaluate class
 * @author Andrej Kogov\u0161ek, Du\u0161an Omer\u010Devi\u0107
 * @version 1.0
 */
public final class Evaluate {
    /**
     * Constructor
     * @param modelFile String object parameter
     * @param attrName String attrName parameter
     * @param variables String variables
     */
    private Evaluate(final String modelFile, final String attrName,
        final String variables) {
        System.out.println("DEXi evaluate");
        System.out.println("==========================");
        System.out.println("Model xml file: " + modelFile);
        System.out.println("Attribute name: " + attrName);
        System.out.println("Variables: " + variables);
        System.out.println("==========================");

        try {
            Model model = new Model(loadFile(modelFile));
            Value value = model.evaluate(attrName, variables);
            System.out.println("Value: " + value.getName());
        } catch (IOException e) {
            System.out.println("Can't read file");
            System.out.println("Error: " + e.getMessage());
        } catch (Exception e) {
            System.out.println("Invalid parameters");
            System.out.println("Error: " + e.getMessage());
        }
    }

    /**
     * Read content of file and return String object
     * @param xmlFile File path
     * @return String object
     * @throws IOException Throws exception
     */
    private String loadFile(final String xmlFile) throws IOException {
        StringBuffer sb = new StringBuffer();

        BufferedReader in = new BufferedReader(new FileReader(xmlFile));
        String xml;

        while ((xml = in.readLine()) != null) {
            sb.append(xml);
        }

        in.close();

        return sb.toString();
    }

    /**
     * Main class
     * @param args Input parameters
     */
    public static void main(final String[] args) {
        if (args.length != 3) {
            System.out.println("Invalid input arguments!");
            System.out.println("1. Argument is xml model");
            System.out.println("2. Argument is attribute name");
            System.out.println("3. Argument is variables");
            System.exit(0);
        }

        new Evaluate(args[0], args[1], args[2]);
    }
}
