////////////////////////////////////////////////////////////////////////////////
//DEXi: Implements a Multi-Attribute Decision Making algorithm developed by
//dr. Marko Bohanec (http://www-ai.ijs.si/MarkoBohanec/dex.html)
//
//Copyright (C) 2004 Asobi d.o.o. (www.asobi.si)
//Authors: dr. Marko Bohanec, Dusan Omercevic, Andrej Kogovsek
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU Lesser General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//Lesser General Public License for more details.
//
//You should have received a copy of the GNU Lesser General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
////////////////////////////////////////////////////////////////////////////////
package si.DEXi;


/**
 * Variable class
 * @author Andrej Kogov\u0161ek, Du\u0161an Omer\u010Devi\u0107
 * @version 1.0
 */
public class Variable {
    private String name;
    private String value;

    /**
     * Constructor with String (name=value) parameter
     * @param hash Input string in format like name1=value1
     */
    public Variable(final String hash) {
        String[] str = hash.split("=");

        if (str.length != 2) {
            throw new IllegalArgumentException("Variable: Invalid value");
        }

        if ((str[0] == null) || str[0].equals("")) {
            throw new IllegalArgumentException("Variable: Name is null");
        }

        if ((str[1] == null) || str[1].equals("")) {
            throw new IllegalArgumentException("Variable: Value is null");
        }

        setName(str[0]);
        setValue(str[1]);
    }

    /**
     * Get name value
     * @return name
     */
    public String getName() {
        return this.name;
    }

    /**
     * Get value
     * @return value
     */
    public String getValue() {
        return this.value;
    }

    /**
     * Set name value
     * @param aName String object parameter
     */
    protected void setName(final String aName) {
        this.name = aName;
    }

    /**
     * Set value
     * @param aValue String object parameter
     */
    protected void setValue(final String aValue) {
        this.value = aValue;
    }
}
